@@ -5,4 +5,8 @@ double RobustBF21fun(int n, int k2, int k0, double Q);
 double LiangBF21fun(int n, int k2, int k0, double Q);
 double ZSBF21fun(int n, int k2, int k0, double Q);
 double Robust2BF21fun(int n, int k2, int k0, double Q);
+double intrinsicBF21fun(int n, int k2, int k0, double Q);
+double geointrinsicBF21fun(int n, int k2, int k0, double Q);
+double geointrinsic2BF21fun(int n, int k2, int k0, double Q);
+
 
